@@ -7,15 +7,15 @@ import logging
 logging.basicConfig(level=logging.INFO)
 
 bed_file = '../data/mouse_long/plink'
-kin_lst = agmat(bed_file, inv=True, small_val=0.001, out_fmt='id_id_val')
+kin_lst = agmat(bed_file, out_file='../data/mouse_long/test', inv=True, small_val=0.001, out_fmt='id_id_val')
 data_file = '../data/mouse_long/phe.unbalance.txt'
 id = 'ID'
 tpoint = 'weak'
 trait = 'trait'
-kin_inv_file = '../data/mouse_long/plink.agiv2'
+kin_inv_file = '../data/mouse_long/test.agiv.id_fmt'
 tfix = 'Sex'
 prefix_outfile = '../data/mouse_long/unbalance_varcom'
-#res_var = unbalance_varcom(data_file, id, tpoint, trait, kin_inv_file, tfix=None, prefix_outfile=prefix_outfile)
+res_var = unbalance_varcom(data_file, id, tpoint, trait, kin_inv_file, tfix=None, prefix_outfile=prefix_outfile)
 #print(res_var)
 
 
