@@ -3,3 +3,7 @@ from gmat.longwas.unbalance.unbalance_longwas_fixed import unbalance_longwas_fix
 from gmat.longwas.unbalance.unbalance_longwas_fixed_permutation import unbalance_longwas_fixed_permutation
 from gmat.longwas.unbalance.unbalance_longwas_trans import unbalance_longwas_trans
 from gmat.longwas.unbalance.unbalance_longwas_trans_permutation import unbalance_longwas_trans_permutation
+
+
+from gmat.longwas.unbalance.unbalance_condition_longwas_fixed import unbalance_condition_longwas_fixed
+from gmat.longwas.unbalance.unbalance_condition_longwas_trans import unbalance_condition_longwas_trans
