@@ -6,9 +6,10 @@ from pysnptools.snpreader import Bed
 from tqdm import tqdm
 from gmat.process_plink.process_plink import impute_geno
 from scipy.stats import chi2
+from scipy.sparse import csc_matrix
 
 
-def fixed(pheno_file, bed_file, agmat_file, out_file='res.txt', npart=100, maxiter0=100, maxiter1=10,
+def fixed(pheno_file, bed_file, agmat_file, out_file='res.txt', condition=None, npart=100, maxiter0=100, maxiter1=10,
           speed=True, pcut=5.0e-5):
     """
     run GWAS based on linear mixed model and put one snp in each analysis.
@@ -19,6 +20,7 @@ def fixed(pheno_file, bed_file, agmat_file, out_file='res.txt', npart=100, maxit
     :param bed_file: the prefix for the plink binary file.
     :param agmat_file: the prefix for the additive genomic relationship matrix file.
     :param out_file: the output file. Default is 'res.txt'.
+    :param condition: A string or a list for the conditional SNP. Default is None.
     :param npart: divide the SNPs into n parts. Default is 100.
     :param maxiter0: the maximum number of iteration for variance estimation in the null model
     :param maxiter1: the maximum number of iteration for variance estimation in testing snp.
@@ -27,10 +29,10 @@ def fixed(pheno_file, bed_file, agmat_file, out_file='res.txt', npart=100, maxit
     :return:
     """
     logging.info("###Prepare the phenotypic values, covariates and genomic matrix")
-    y, xmat, ag, id_keep = _pre_pheno(pheno_file, agmat_file)
+    y, xmat, zmat, ag, id_keep = _pre_pheno(pheno_file, agmat_file)
     logging.info("###Estimate the variances in the null model.")
     init = np.array([np.var(y) / 2] * 2)
-    gmat_eigenvals, gmat_eigenvecs = linalg.eigh(ag)
+    gmat_eigenvals, gmat_eigenvecs = linalg.eigh(zmat.dot((zmat.dot(ag)).T))
     gmat_eigenvals = np.array(gmat_eigenvals).reshape(-1, 1)
     y_trans = np.dot(gmat_eigenvecs.T, y)  # transform the phenotypic values
     xmat_trans = np.dot(gmat_eigenvecs.T, xmat)  # transform the fixed effects
@@ -48,6 +50,16 @@ def fixed(pheno_file, bed_file, agmat_file, out_file='res.txt', npart=100, maxit
     for i in range(npart):
         snp_index.append(int(num_snp / npart) * i)
     snp_index.append(num_snp)
+    if condition is not None:
+        if not isinstance(condition, list):
+            condition = [condition]
+        condition_snp_index = snp_on_disk.sid_to_index(condition)
+        condition_snp_val = snp_on_disk[id_keep_ind, condition_snp_index].read().val
+        if np.any(np.isnan(condition_snp_val)):
+            logging.info('Missing genotypes of conditional SNP are imputed with random genotypes.')
+            condition_snp_val = impute_geno(condition_snp_val)
+        condition_snp_val = np.dot(gmat_eigenvecs.T, condition_snp_val)
+        xmat_trans = np.concatenate([xmat_trans, condition_snp_val], axis=1)
     logging.info('###Start the association')
     with open(out_file, 'w') as fout:
         fout.write('\t'.join(['chro', 'snp_ID', 'pos', 'allele1', 'allele2', 'cc', 'eff', 'se', 'p_wald']))
@@ -160,8 +172,17 @@ def _pre_pheno(pheno_file, agmat_file):
                     del e
     y = np.array(y).reshape(-1, 1)
     xmat = np.array(xmat)
-    id_dct = dict(zip(id_keep, range(len(id_keep))))
-    ag = np.zeros((len(id_keep), len(id_keep)))
+    val = 0
+    id_dct = {}
+    col = []
+    for v in id_keep:
+        if v not in id_dct:
+            id_dct[v] = val
+            val += 1
+        col.append(id_dct[v])
+    row = range(len(id_keep))
+    zmat = csc_matrix(([1.0]*len(row), (row, col)))
+    ag = np.zeros((len(id_dct), len(id_dct)))
     with open(agmat_file + '.agrm.id_fmt') as fin:
         for line in fin:
             arr = line.split()
@@ -169,7 +190,7 @@ def _pre_pheno(pheno_file, agmat_file):
                 ag[id_dct[arr[0]], id_dct[arr[1]]] = ag[id_dct[arr[1]], id_dct[arr[0]]] = float(arr[2])
             except Exception as e:
                 del e
-    return y, xmat, ag, id_keep
+    return y, xmat, zmat, ag, id_keep
 
 
 def _weight_emai_eigen(y_trans, xmat_trans, gmat_eigenvals, init=None, maxiter=100, cc=1.0e-8):
