@@ -18,10 +18,9 @@ def ai_vmat(y, xmat, zmat_lst, gmat_lst, init=None, maxiter=100, cc_par=1.0e-8):
     """
     logging.info("#####Prepare#####")
     num_var = len(gmat_lst) + 1
-    var_com = [1.0] * (num_var)
+    var_com = np.ones(num_var)
     if init is not None:
-        var_com = init[:]
-    var_com = np.array(var_com)
+        var_com = np.array(init)
     y = np.array(y).reshape(-1, 1)
     n = y.shape[0]
     xmat = np.array(xmat).reshape(n, -1)
@@ -90,14 +89,19 @@ def ai_mme(y, xmat, zmat_lst, gmat_inv_lst, init=None, maxiter=100, cc_par=1.0e-
     var_com = np.ones(num_var)
     if init is not None:
         var_com = np.array(init)
-    logging.info("Prepare the coef matrix without variance parameters")
-    xmat_df = xmat.shape[1]
-    n = xmat.shape[0]
     y = np.array(y).reshape(-1, 1)
+    n = y.shape[0]
+    xmat = np.array(xmat).reshape(n, -1)
+    xmat_df = xmat.shape[1]
+    df_index = [xmat_df]  # the index for the degree of freedom for different effects.
+    for i in range(num_var - 1):
+        df_index.append(df_index[-1] + gmat_inv_lst[i].shape[0])
+    logging.info("Prepare the coefficient matrix without variance parameters")
     zmat_concat = hstack(zmat_lst)
     xzmat = hstack([xmat, zmat_concat])
-    coef_null = xzmat.T.dot(xzmat)
-    rhs_null = xzmat.T.dot(y)
+    coef_null = xzmat.T.dot(xzmat)  # the coefficient matrix
+    rhs_null = xzmat.T.dot(y)  # the right hand matrix
+    logging.info('Initial variances: ' + ' '.join(list(np.array(var_com, dtype=str))))
     logging.info("Start iteration")
     iter = 0
     cc_par_val = 10000.0
@@ -106,11 +110,9 @@ def ai_mme(y, xmat, zmat_lst, gmat_inv_lst, init=None, maxiter=100, cc_par=1.0e-
         logging.info('Round: {:d}'.format(iter))
         # coef matrix
         coef = coef_null.toarray() / var_com[-1]
-        df_sum = xmat_df
         for k in range(num_var - 1):
-            indexa = df_sum
-            df_sum += gmat_inv_lst[k].shape[0]
-            indexb = df_sum
+            indexa = df_index[k]
+            indexb = df_index[k + 1]
             coef[indexa:indexb, indexa:indexb] = coef[indexa:indexb, indexa:indexb] + gmat_inv_lst[k] / var_com[k]
         # right hand
         rhs_mat = rhs_null / var_com[-1]
@@ -120,11 +122,9 @@ def ai_mme(y, xmat, zmat_lst, gmat_inv_lst, init=None, maxiter=100, cc_par=1.0e-
         # first partial derivatives and working variates
         fd_mat = np.zeros(num_var)
         wv_mat = []
-        df_sum = xmat_df
         for i in range(num_var - 1):
-            indexa = df_sum
-            df_sum += gmat_inv_lst[i].shape[0]
-            indexb = df_sum
+            indexa = df_index[i]
+            indexb = df_index[i + 1]
             fd_mat[i] = np.sum(coef_inv[indexa:indexb, indexa:indexb] * gmat_inv_lst[i]) + \
                         np.sum(reduce(np.dot, [eff[indexa:indexb, :].T, gmat_inv_lst[i], eff[indexa:indexb, :]]))
             fd_mat[i] = -0.5 * gmat_inv_lst[i].shape[0]/var_com[i] + 0.5 * fd_mat[i] / (var_com[i] * var_com[i])
